API Reference — bcselector 0.0.38 documentation

# API Reference

This page gives an overview of all bcselector objects and functions.

- Feature Selectors
  - FractionVariableSelector
  - DiffVariableSelector
- Data Generation
  - MatrixGenerator
  - DataFrameGenerator
- Datasets
  - load_sample
  - load_hepatitis
- Information Theory
  - Basic Approximations
  - J Criterion Approximations
- Filter Methods
  - Cost Based Filter Methods
  - No-Cost Based Filter Methods